@@ -18,11 +18,11 @@ func (e *csvEncoder) CanHandleAliases() bool {
 	return false
 }
 
-func (e *csvEncoder) PrintDocumentSeparator(writer io.Writer) error {
+func (e *csvEncoder) PrintDocumentSeparator(_ io.Writer) error {
 	return nil
 }
 
-func (e *csvEncoder) PrintLeadingContent(writer io.Writer, content string) error {
+func (e *csvEncoder) PrintLeadingContent(_ io.Writer, _ string) error {
 	return nil
 }
 
